# A python library for your Aton Storage system

**This project is not affiliated, associated, authorized, endorsed by, or in any way officially connected with Aton Green Storage, or any of its subsidiaries or its affiliates. The official Aton Green Storage website can be found at http://www.atonstorage.com.**

Pyaton is a simple library for getting data from your Aton Storage photovoltaic system.
